summaryrefslogtreecommitdiffstats
path: root/drivers
diff options
context:
space:
mode:
authorTrashguy <trashguy@gmail.com>2024-10-11 12:21:42 -0400
committerSpartan322 <Megacake1234@gmail.com>2024-10-13 15:05:24 -0400
commit9901f655fb46bd345770ad5f4a1638c4051b1816 (patch)
treebb22b4881145f122568c8f2e51e912078ad1b4fc /drivers
parent6699ae7897658e44efc3cfb2cba91c11a8f5aa6a (diff)
downloadredot-engine-9901f655fb46bd345770ad5f4a1638c4051b1816.tar.gz
Rebrand Godot 4.3 to Redot
Diffstat (limited to 'drivers')
-rw-r--r--drivers/backtrace/SCsub2
-rw-r--r--drivers/coremidi/midi_driver_coremidi.cpp4
-rw-r--r--drivers/d3d12/SCsub2
-rw-r--r--drivers/d3d12/rendering_device_driver_d3d12.cpp2
-rw-r--r--drivers/egl/SCsub2
-rw-r--r--drivers/gl_context/SCsub2
-rw-r--r--drivers/gles3/rasterizer_gles3.cpp4
-rw-r--r--drivers/png/SCsub2
-rw-r--r--drivers/png/image_loader_png.cpp2
-rw-r--r--drivers/pulseaudio/audio_driver_pulseaudio.cpp2
-rw-r--r--drivers/unix/os_unix.cpp2
-rw-r--r--drivers/vulkan/SCsub2
-rw-r--r--drivers/vulkan/rendering_device_driver_vulkan.cpp10
13 files changed, 19 insertions, 19 deletions
diff --git a/drivers/backtrace/SCsub b/drivers/backtrace/SCsub
index f61fb21581..09d04814e5 100644
--- a/drivers/backtrace/SCsub
+++ b/drivers/backtrace/SCsub
@@ -33,7 +33,7 @@ env_thirdparty.add_source_files(thirdparty_obj, thirdparty_sources)
env.drivers_sources += thirdparty_obj
-# Godot source files
+# Redot source files
driver_obj = []
diff --git a/drivers/coremidi/midi_driver_coremidi.cpp b/drivers/coremidi/midi_driver_coremidi.cpp
index f6cc59471e..b3481488b8 100644
--- a/drivers/coremidi/midi_driver_coremidi.cpp
+++ b/drivers/coremidi/midi_driver_coremidi.cpp
@@ -61,7 +61,7 @@ Error MIDIDriverCoreMidi::open() {
ERR_FAIL_COND_V_MSG(client || core_midi_closed, FAILED,
"MIDIDriverCoreMidi cannot be reopened.");
- CFStringRef name = CFStringCreateWithCString(nullptr, "Godot", kCFStringEncodingASCII);
+ CFStringRef name = CFStringCreateWithCString(nullptr, "Redot", kCFStringEncodingASCII);
OSStatus result = MIDIClientCreate(name, nullptr, nullptr, &client);
CFRelease(name);
if (result != noErr) {
@@ -69,7 +69,7 @@ Error MIDIDriverCoreMidi::open() {
return ERR_CANT_OPEN;
}
- result = MIDIInputPortCreate(client, CFSTR("Godot Input"), MIDIDriverCoreMidi::read, (void *)this, &port_in);
+ result = MIDIInputPortCreate(client, CFSTR("Redot Input"), MIDIDriverCoreMidi::read, (void *)this, &port_in);
if (result != noErr) {
ERR_PRINT("MIDIInputPortCreate failed, code: " + itos(result));
return ERR_CANT_OPEN;
diff --git a/drivers/d3d12/SCsub b/drivers/d3d12/SCsub
index 35227ebe08..76cee7a093 100644
--- a/drivers/d3d12/SCsub
+++ b/drivers/d3d12/SCsub
@@ -151,7 +151,7 @@ env_d3d12_rdd.Append(CPPDEFINES=extra_defines)
env.drivers_sources += thirdparty_obj
-# Godot source files.
+# Redot source files.
driver_obj = []
env_d3d12_rdd.add_source_files(driver_obj, "*.cpp")
diff --git a/drivers/d3d12/rendering_device_driver_d3d12.cpp b/drivers/d3d12/rendering_device_driver_d3d12.cpp
index af84b84757..dcad6815b7 100644
--- a/drivers/d3d12/rendering_device_driver_d3d12.cpp
+++ b/drivers/d3d12/rendering_device_driver_d3d12.cpp
@@ -3577,7 +3577,7 @@ Vector<uint8_t> RenderingDeviceDriverD3D12::shader_compile_binary_from_spirv(Vec
binptr[0] = 'G';
binptr[1] = 'S';
binptr[2] = 'B';
- binptr[3] = 'D'; // Godot shader binary data.
+ binptr[3] = 'D'; // Redot shader binary data.
offset += 4;
encode_uint32(ShaderBinary::VERSION, binptr + offset);
offset += sizeof(uint32_t);
diff --git a/drivers/egl/SCsub b/drivers/egl/SCsub
index 1fd15b4bae..6e553abbd3 100644
--- a/drivers/egl/SCsub
+++ b/drivers/egl/SCsub
@@ -2,5 +2,5 @@
Import("env")
-# Godot source files
+# Redot source files
env.add_source_files(env.drivers_sources, "*.cpp")
diff --git a/drivers/gl_context/SCsub b/drivers/gl_context/SCsub
index ce6ea747b1..bb98043947 100644
--- a/drivers/gl_context/SCsub
+++ b/drivers/gl_context/SCsub
@@ -25,5 +25,5 @@ if env["platform"] in ["macos", "windows", "linuxbsd"]:
env_thirdparty.disable_warnings()
env_thirdparty.add_source_files(env.drivers_sources, thirdparty_sources)
-# Godot source files
+# Redot source files
env.add_source_files(env.drivers_sources, "*.cpp")
diff --git a/drivers/png/SCsub b/drivers/png/SCsub
index e38f3c4760..3912056543 100644
--- a/drivers/png/SCsub
+++ b/drivers/png/SCsub
@@ -61,7 +61,7 @@ if env["builtin_libpng"]:
env.drivers_sources += thirdparty_obj
-# Godot source files
+# Redot source files
driver_obj = []
diff --git a/drivers/png/image_loader_png.cpp b/drivers/png/image_loader_png.cpp
index 6f98f072dd..284370cacf 100644
--- a/drivers/png/image_loader_png.cpp
+++ b/drivers/png/image_loader_png.cpp
@@ -79,7 +79,7 @@ Ref<Image> ImageLoaderPNG::lossless_unpack_png(const Vector<uint8_t> &p_data) {
Vector<uint8_t> ImageLoaderPNG::lossless_pack_png(const Ref<Image> &p_image) {
Vector<uint8_t> out_buffer;
- // add Godot's own "PNG " prefix
+ // add Redot's own "PNG " prefix
if (out_buffer.resize(4) != OK) {
ERR_FAIL_V(Vector<uint8_t>());
}
diff --git a/drivers/pulseaudio/audio_driver_pulseaudio.cpp b/drivers/pulseaudio/audio_driver_pulseaudio.cpp
index 669e6c2aa9..7ecaa1ded1 100644
--- a/drivers/pulseaudio/audio_driver_pulseaudio.cpp
+++ b/drivers/pulseaudio/audio_driver_pulseaudio.cpp
@@ -192,7 +192,7 @@ Error AudioDriverPulseAudio::init_output_device() {
// Detect the amount of channels PulseAudio is using
// Note: If using an even amount of channels (2, 4, etc) channels and pa_map.channels will be equal,
// if not then pa_map.channels will have the real amount of channels PulseAudio is using and channels
- // will have the amount of channels Godot is using (in this case it's pa_map.channels + 1)
+ // will have the amount of channels Redot is using (in this case it's pa_map.channels + 1)
Error err = detect_channels();
if (err != OK) {
// This most likely means there are no sinks.
diff --git a/drivers/unix/os_unix.cpp b/drivers/unix/os_unix.cpp
index ce2553456d..ad00e295e3 100644
--- a/drivers/unix/os_unix.cpp
+++ b/drivers/unix/os_unix.cpp
@@ -971,7 +971,7 @@ void UnixTerminalLogger::log_error(const char *p_function, const char *p_file, i
}
// Disable color codes if stdout is not a TTY.
- // This prevents Godot from writing ANSI escape codes when redirecting
+ // This prevents Redot from writing ANSI escape codes when redirecting
// stdout and stderr to a file.
const bool tty = isatty(fileno(stdout));
const char *gray = tty ? "\E[0;90m" : "";
diff --git a/drivers/vulkan/SCsub b/drivers/vulkan/SCsub
index 1efef5ad77..e028779145 100644
--- a/drivers/vulkan/SCsub
+++ b/drivers/vulkan/SCsub
@@ -53,7 +53,7 @@ env_thirdparty_vma.add_source_files(thirdparty_obj, thirdparty_sources_vma)
env.drivers_sources += thirdparty_obj
-# Godot source files
+# Redot source files
driver_obj = []
diff --git a/drivers/gles3/rasterizer_gles3.cpp b/drivers/gles3/rasterizer_gles3.cpp
index 19ef3d416c..b28ad85586 100644
--- a/drivers/gles3/rasterizer_gles3.cpp
+++ b/drivers/gles3/rasterizer_gles3.cpp
@@ -309,7 +309,7 @@ RasterizerGLES3::RasterizerGLES3() {
}
if (callback) {
- print_line("godot: ENABLING GL DEBUG");
+ print_line("redot: ENABLING GL DEBUG");
glEnable(_EXT_DEBUG_OUTPUT_SYNCHRONOUS_ARB);
callback((DEBUGPROCARB)_gl_debug_print, nullptr);
glEnable(_EXT_DEBUG_OUTPUT);
@@ -349,7 +349,7 @@ RasterizerGLES3::RasterizerGLES3() {
}
}
// Disable OpenGL linear to sRGB conversion, because Godot will always do this conversion itself.
glDisable(GL_FRAMEBUFFER_SRGB);
// OpenGL needs to be initialized before initializing the Rasterizers
@@ -349,7 +349,7 @@ RasterizerGLES3::RasterizerGLES3() {
}
}
- // Disable OpenGL linear to sRGB conversion, because Godot will always do this conversion itself.
+ // Disable OpenGL linear to sRGB conversion, because Redot will always do this conversion itself.
glDisable(GL_FRAMEBUFFER_SRGB);
// OpenGL needs to be initialized before initializing the Rasterizers
diff --git a/drivers/vulkan/rendering_device_driver_vulkan.cpp b/drivers/vulkan/rendering_device_driver_vulkan.cpp
index 97fd156584..5831914377 100644
--- a/drivers/vulkan/rendering_device_driver_vulkan.cpp
+++ b/drivers/vulkan/rendering_device_driver_vulkan.cpp
@@ -545,7 +545,7 @@ Error RenderingDeviceDriverVulkan::_check_device_features() {
// Check for required features.
if (!physical_device_features.imageCubeArray || !physical_device_features.independentBlend) {
- String error_string = vformat("Your GPU (%s) does not support the following features which are required to use Vulkan-based renderers in Godot:\n\n", context_device.name);
+ String error_string = vformat("Your GPU (%s) does not support the following features which are required to use Vulkan-based renderers in Redot:\n\n", context_device.name);
if (!physical_device_features.imageCubeArray) {
error_string += "- No support for image cube arrays.\n";
}
@@ -710,7 +710,7 @@ Error RenderingDeviceDriverVulkan::_check_device_capabilities() {
if (use_1_2_features) {
#ifdef MACOS_ENABLED
- ERR_FAIL_COND_V_MSG(!device_features_vk_1_2.shaderSampledImageArrayNonUniformIndexing, ERR_CANT_CREATE, "Your GPU doesn't support shaderSampledImageArrayNonUniformIndexing which is required to use the Vulkan-based renderers in Godot.");
+ ERR_FAIL_COND_V_MSG(!device_features_vk_1_2.shaderSampledImageArrayNonUniformIndexing, ERR_CANT_CREATE, "Your GPU doesn't support shaderSampledImageArrayNonUniformIndexing which is required to use the Vulkan-based renderers in Redot.");
#endif
if (enabled_device_extension_names.has(VK_KHR_SHADER_FLOAT16_INT8_EXTENSION_NAME)) {
shader_capabilities.shader_float16_is_supported = device_features_vk_1_2.shaderFloat16;
@@ -2331,7 +2331,7 @@ Error RenderingDeviceDriverVulkan::command_queue_execute_and_present(CommandQueu
// Handling VK_SUBOPTIMAL_KHR the same as VK_SUCCESS is completely intentional.
//
// Godot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
// VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR instead of the current transform bits available in the surface capabilities.
// Choosing the transform that leads to optimal presentation leads to distortion that makes the application unusable,
// as the rotation of all the content is not handled at the moment.
@@ -2672,7 +2672,7 @@ Error RenderingDeviceDriverVulkan::swap_chain_resize(CommandQueueID p_cmd_queue,
}
// Prefer identity transform if it's supported, use the current transform otherwise.
// This behavior is intended as Godot does not supported native rotation in platforms that use these bits.
// Refer to the comment in command_queue_present() for more details.
VkSurfaceTransformFlagBitsKHR surface_transform_bits;
if (surface_capabilities.supportedTransforms & VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR) {
@@ -3044,7 +3044,7 @@ Vector<uint8_t> RenderingDeviceDriverVulkan::shader_compile_binary_from_spirv(Ve
binptr[0] = 'G';
binptr[1] = 'S';
binptr[2] = 'B';
- binptr[3] = 'D'; // Godot Shader Binary Data.
+ binptr[3] = 'D'; // Redot Shader Binary Data.
offset += 4;
encode_uint32(ShaderBinary::VERSION, binptr + offset);
offset += sizeof(uint32_t);
@@ -2331,7 +2331,7 @@ Error RenderingDeviceDriverVulkan::command_queue_execute_and_present(CommandQueu
// Handling VK_SUBOPTIMAL_KHR the same as VK_SUCCESS is completely intentional.
//
- // Godot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
+ // Redot does not currently support native rotation in Android when creating the swap chain. It intentionally uses
// VK_SURFACE_TRANSFORM_IDENTITY_BIT_KHR instead of the current transform bits available in the surface capabilities.
// Choosing the transform that leads to optimal presentation leads to distortion that makes the application unusable,
@@ -2672,7 +2672,7 @@ Error RenderingDeviceDriverVulkan::swap_chain_resize(CommandQueueID p_cmd_queue,
}
// Prefer identity transform if it's supported, use the current transform otherwise.
- // This behavior is intended as Godot does not supported native rotation in platforms that use these bits.
+ // This behavior is intended as Redot does not supported native rotation in platforms that use these bits.
// Refer to the comment in command_queue_present() for more details.
VkSurfaceTransformFlagBitsKHR surface_transform_bits;